import{S as p}from"./Sidebar.a67faba2.js";import{_ as d}from"./Navbar.vue_vue_type_script_setup_true_lang.6ea05ef8.js";import{M as c,N as l,O as u}from"./icons.52647ede.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.9a751704.js";import{a as w}from"./asyncComputed.c0b7f526.js";import"./router.2ed86b1e.js";import"./index.1dbbc1f9.js";import{O as z}from"./organization.b6a6d651.js";import{B as h}from"./BaseLayout.fa38ee82.js";import"./index.b69d7ab2.js";import"./logo.084e5d7c.js";import"./Text.0538649f.js";import"./Base.083cbb66.js";import"./Typography.c485b72c.js";import"./index.2b2cc95e.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.b9d05841.js";import"./hasIn.c089c9ed.js";import"./index.cf4c23b9.js";import"./record.91b90880.js";import"./pubsub.f352a300.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="6a53e05a-6ad5-40eb-84de-70dd6a957749",o._sentryDebugIdIdentifier="sentry-dbid-6a53e05a-6ad5-40eb-84de-70dd6a957749")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:c,path:"projects"},{name:"Editors",icon:l,path:"editors"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(d,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.649085d6.js.map
