import{g as i}from"./api.46b6c86f.js";import{P as m}from"./Passwordless.c3fe98b1.js";import{a as p}from"./asyncComputed.c0b7f526.js";import{W as u}from"./WidgetsFrame.71cf9de2.js";import{d as f,eA as l,eB as _,b as d,ev as y,e as b,u as s,c as g,w as h,ex as w,f as v,v as k}from"./outputWidgets.9a751704.js";import"./runnerData.343344af.js";import"./url.a9a0a879.js";import"./index.06053586.js";import"./pubsub.f352a300.js";import"./icons.52647ede.js";import"./CircularLoading.588d4903.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="86c8bf7d-77b4-4c51-b43a-58ce6737da8e",e._sentryDebugIdIdentifier="sentry-dbid-86c8bf7d-77b4-4c51-b43a-58ce6737da8e")}catch{}})();const x={class:"login"},I=f({__name:"Login",setup(e){const t=l(),a=_(),{result:o}=p(i),c=()=>{const{redirect:r,...n}=a.query;if(r){t.push({path:r,query:n,params:a.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(d(),y("div",null,[b("div",x,[s(o)?(d(),g(u,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:c})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.32406223.js.map
