import"./outputWidgets.9a751704.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="45eb3525-ef38-41e1-bb5a-9441437fc045",e._sentryDebugIdIdentifier="sentry-dbid-45eb3525-ef38-41e1-bb5a-9441437fc045")}catch{}})();function d(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}export{d as g};
//# sourceMappingURL=datetime.097b969b.js.map
