import"./outputWidgets.9a751704.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a9bbcab2-e9ab-4b32-9925-59bedbf95e58",e._sentryDebugIdIdentifier="sentry-dbid-a9bbcab2-e9ab-4b32-9925-59bedbf95e58")}catch{}})();function l(e){return e.charAt(0).toUpperCase()+e.slice(1)}function u(e,a,n=!1,t=!0){const s=(t?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,"").replace(/[^a-zA-Z0-9]/g,"_"),c=n?s:s.replace(/_+/g,"_");return a?c:c.replace(/_$/,"")}function d(e){var o;const n=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,r=n.match(t);return(o=r==null?void 0:r.join("-"))!=null?o:""}function b(e){try{return{valid:!0,parsed:JSON.parse(e)}}catch(a){return{valid:!1,message:a.message}}}export{d as a,l as c,u as n,b as v};
//# sourceMappingURL=string.8b9c7f23.js.map
