import{u as s}from"./index.06053586.js";import{d,b as c,ev as f,f as p,u as r}from"./outputWidgets.9a751704.js";import{g as l}from"./api.46b6c86f.js";import{K as u,L as b}from"./repository.5c82adf6.js";import{_ as g}from"./Navbar.vue_vue_type_script_setup_true_lang.be5e2a9d.js";import{a as y}from"./asyncComputed.c0b7f526.js";import{P as _}from"./repository.78fce6ed.js";import"./pubsub.f352a300.js";import"./runnerData.343344af.js";import"./url.a9a0a879.js";import"./api.3ed9328f.js";import"./index.cf4c23b9.js";import"./icons.52647ede.js";import"./ant-design.d5cba7d2.js";import"./index.9a36e5c2.js";import"./Modal.34cd8ce8.js";import"./Text.0538649f.js";import"./Base.083cbb66.js";import"./Typography.c485b72c.js";import"./index.24643c9a.js";import"./Link.76792a23.js";import"./Paragraph.ee49e077.js";import"./Title.9671cb18.js";import"./index.6edb660d.js";import"./index.b69d7ab2.js";import"./index.9b7844f2.js";import"./index.2608a00b.js";import"./CollapsePanel.c7020b99.js";import"./Form.b9d05841.js";import"./hasIn.c089c9ed.js";import"./Timeline.e6c6c7ca.js";import"./index.120795b6.js";import"./index.2dbefe32.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.c779fa28.js";import"./workspaces.3409a8a6.js";import"./record.91b90880.js";import"./scripts.f0b00021.js";import"./envVars.f2043939.js";import"./ExpandOutlined.8e78e137.js";import"./Card.84115cfb.js";import"./TabPane.20c6a7e7.js";import"./index.2b2cc95e.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="40ed1224-0247-481f-8c9c-cddbde768212",o._sentryDebugIdIdentifier="sentry-dbid-40ed1224-0247-481f-8c9c-cddbde768212")}catch{}})();const fo=d({__name:"Kanban",setup(o){const t=new _(s),i=new b("kanban"),{result:e}=y(l);return(k,w)=>{var m,n,a;return c(),f("div",null,[p(g,{"brand-name":((m=r(e))==null?void 0:m.brandName)||((n=r(e))==null?void 0:n.name),"logo-url":(a=r(e))==null?void 0:a.logoUrl},null,8,["brand-name","logo-url"]),p(u,{"kanban-repository":r(t),storage:r(i)},null,8,["kanban-repository","storage"])])}}});export{fo as default};
//# sourceMappingURL=Kanban.5acb5bca.js.map
