import{K as n,L as p}from"./repository.5c82adf6.js";import{E as s}from"./repository.78fce6ed.js";import{d as a,b as m,c,u as e}from"./outputWidgets.9a751704.js";import{l as d}from"./index.06053586.js";import"./asyncComputed.c0b7f526.js";import"./api.3ed9328f.js";import"./index.cf4c23b9.js";import"./icons.52647ede.js";import"./ant-design.d5cba7d2.js";import"./index.9a36e5c2.js";import"./Modal.34cd8ce8.js";import"./Text.0538649f.js";import"./Base.083cbb66.js";import"./Typography.c485b72c.js";import"./index.24643c9a.js";import"./Link.76792a23.js";import"./Paragraph.ee49e077.js";import"./Title.9671cb18.js";import"./index.6edb660d.js";import"./index.b69d7ab2.js";import"./index.9b7844f2.js";import"./index.2608a00b.js";import"./CollapsePanel.c7020b99.js";import"./Form.b9d05841.js";import"./hasIn.c089c9ed.js";import"./Timeline.e6c6c7ca.js";import"./index.120795b6.js";import"./index.2dbefe32.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.c779fa28.js";import"./workspaces.3409a8a6.js";import"./runnerData.343344af.js";import"./url.a9a0a879.js";import"./record.91b90880.js";import"./pubsub.f352a300.js";import"./scripts.f0b00021.js";import"./envVars.f2043939.js";import"./ExpandOutlined.8e78e137.js";import"./Card.84115cfb.js";import"./TabPane.20c6a7e7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="057b62ec-1ee1-4db5-9752-5fa366896df5",t._sentryDebugIdIdentifier="sentry-dbid-057b62ec-1ee1-4db5-9752-5fa366896df5")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const to=a({__name:"WorkflowKanban",setup(t){const o=new s,r=new f,i=new p("kanban");return(u,b)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{to as default};
//# sourceMappingURL=WorkflowKanban.52fcca93.js.map
