import"./outputWidgets.9a751704.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="8c2adee7-cf2c-4731-af3d-197ac6afdf89",e._sentryDebugIdIdentifier="sentry-dbid-8c2adee7-cf2c-4731-af3d-197ac6afdf89")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.a9a0a879.js.map
