import{B as d}from"./Base.083cbb66.js";import{A as o}from"./Link.76792a23.js";import{A as r}from"./Paragraph.ee49e077.js";import{A as a}from"./Text.0538649f.js";import{A as i}from"./Title.9671cb18.js";import{T as e}from"./Typography.c485b72c.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="3cc39848-3976-4c1f-addf-6f1714cfd973",n._sentryDebugIdIdentifier="sentry-dbid-3cc39848-3976-4c1f-addf-6f1714cfd973")}catch{}})();e.Text=a;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=d;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.24643c9a.js.map
