import{v as t,b as s,ev as o}from"./outputWidgets.9a751704.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="62f098d0-3b93-4359-a4dc-63738791780b",e._sentryDebugIdIdentifier="sentry-dbid-62f098d0-3b93-4359-a4dc-63738791780b")}catch{}})();const r={},d={class:"organization-settings"};function i(e,n){return s(),o("div",d,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.4e686d99.js.map
