import{C as t,A as m}from"./CollapsePanel.c7020b99.js";import{F as n}from"./Form.b9d05841.js";import{aM as i,co as r}from"./outputWidgets.9a751704.js";import{T as o,A as s}from"./Timeline.e6c6c7ca.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="1f268abd-4188-42e1-9d73-177b177dd98c",e._sentryDebugIdIdentifier="sentry-dbid-1f268abd-4188-42e1-9d73-177b177dd98c")}catch{}})();t.Panel=m;t.install=function(e){return e.component(t.name,t),e.component(m.name,m),e};n.useInjectFormItemContext=i;n.ItemRest=r;n.install=function(e){return e.component(n.name,n),e.component(n.Item.name,n.Item),e.component(r.name,r),e};o.Item=s;o.install=function(e){return e.component(o.name,o),e.component(s.name,s),e};
//# sourceMappingURL=index.2608a00b.js.map
