import{ac as f,V as t,Q as r,f as p}from"./outputWidgets.9a751704.js";import{B as l,b as c}from"./Base.083cbb66.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="70b26012-7f60-4e41-a64f-276979530353",e._sentryDebugIdIdentifier="sentry-dbid-70b26012-7f60-4e41-a64f-276979530353")}catch{}})();const b=()=>t(t({},r(c(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:i}=s;const{ellipsis:n}=e;f();const d=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),i);return p(l,d,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=b();const g=o;export{g as A};
//# sourceMappingURL=Text.0538649f.js.map
