import{cz as r}from"./outputWidgets.9a751704.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="f2e10e84-4dda-4215-b477-87f72e36154d",e._sentryDebugIdIdentifier="sentry-dbid-f2e10e84-4dda-4215-b477-87f72e36154d")}catch{}})();const t=(e,d)=>{r.error({message:e,description:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.aacf950f.js.map
