import{eP as n,eQ as t}from"./outputWidgets.9a751704.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="a88915d1-8f32-4f6b-bff3-0520f5cc82e6",e._sentryDebugIdIdentifier="sentry-dbid-a88915d1-8f32-4f6b-bff3-0520f5cc82e6")}catch{}})();function o(e,f){return n(1,arguments),t(e,Date.now(),f)}export{o as f};
//# sourceMappingURL=index.9b7844f2.js.map
