import{v as a,a as r,b as i,c,j as p,T as d,k as _,P as u,C as f,M as l,s as g,l as s,m,n as y,p as b,q as v}from"./outputWidgets.9a751704.js";import{s as w,a as o}from"./index.06053586.js";import"./pubsub.f352a300.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="969a7a34-3311-476e-a5f8-08e250b56fc4",e._sentryDebugIdIdentifier="sentry-dbid-969a7a34-3311-476e-a5f8-08e250b56fc4")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=a(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=p({render:()=>m(k)});d.init(),_(e,o),x.init(),e.use(o),e.use(u),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,b),s(e,v)})();
//# sourceMappingURL=player.0d46c904.js.map
