import{V as s,f as d,Q as p}from"./outputWidgets.9a751704.js";import{B as f,b as i}from"./Base.083cbb66.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="4e96fd2f-7c92-4638-aea2-45a11dc5df2f",a._sentryDebugIdIdentifier="sentry-dbid-4e96fd2f-7c92-4638-aea2-45a11dc5df2f")}catch{}})();const c=()=>p(i(),["component"]),r=(a,e)=>{let{slots:t,attrs:o}=e;const n=s(s(s({},a),{component:"div"}),o);return d(f,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=c();const l=r;export{l as A};
//# sourceMappingURL=Paragraph.ee49e077.js.map
